=======
Credits
=======

Development Lead
----------------

* Inovatho <inovacao@catho.com>

Contributors
------------

* Ivan Marin <ispmarin@gmail.com>
* Bruno Rocha <rochacbruno@gmail.com>
* Rafel Calsaverini <rcalsaverini@gmail.com>
* Emanuel Vianna <emannuelvianna@gmail.com>
